==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Block/InsertBlock/ts/InsertBlock_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Insert</name>
    <message>
        <source>Position</source>
        <translation type="obsolete">Posición</translation>
    </message>
    <message>
        <source>&amp;Insert Block</source>
        <translation type="obsolete">&amp;Insertar bloque</translation>
    </message>
</context>
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+107"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Insertar bloque</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotación:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Girar bloque de&lt;br&gt;este punto de vista</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Escala X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Escala el bloque en X&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Escala el bloque en Y&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Mantener proporciones</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Voltear bloque horizontal</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Voltear bloque&lt;br&gt;verticalmente</translation>
    </message>
    <message>
        <source>Attribute 1:</source>
        <translation type="obsolete">Attribute 1:</translation>
    </message>
    <message>
        <source>Attribute 2:</source>
        <translation type="obsolete">Attribute 2:</translation>
    </message>
    <message>
        <source>Attribute 3:</source>
        <translation type="obsolete">Attribute 3:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">Rotación:</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">Girar bloque de&lt;br&gt;este punto de vista</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">Escala X:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">Escala el bloque en X&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">Mantener proporciones</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">Escala Y:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Escala el bloque en Y&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">Voltear bloque horizontal</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">Voltear bloque&lt;br&gt;verticalmente</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Block/InsertBlock/ts/InsertBlock_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Insert</name>
    <message>
        <source>Position</source>
        <translation type="obsolete">Posición</translation>
    </message>
    <message>
        <source>&amp;Insert Block</source>
        <translation type="obsolete">&amp;Insertar bloque</translation>
    </message>
</context>
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Insertar bloque</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotación:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Girar bloque de&lt;br&gt;este punto de vista</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Escala X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Escala el bloque en X&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Escala el bloque en Y&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Mantener proporciones</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Voltear bloque horizontal</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Voltear bloque&lt;br&gt;verticalmente</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation>Bloque individual</translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation>Matriz de los bloques</translation>
    </message>
    <message>
        <source>Attribute 1:</source>
        <translation type="obsolete">Attribute 1:</translation>
    </message>
    <message>
        <source>Attribute 2:</source>
        <translation type="obsolete">Attribute 2:</translation>
    </message>
    <message>
        <source>Attribute 3:</source>
        <translation type="obsolete">Attribute 3:</translation>
    </message>
    <message>
        <source>Move / Copy Options</source>
        <translation type="obsolete">Opciones de mover / copiar</translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>Columnas:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>Filas:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>Espacio entre columnas:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>Espacio entre filas:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">Rotación:</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">Girar bloque de&lt;br&gt;este punto de vista</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">Escala X:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">Escala el bloque en X&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">Mantener proporciones</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">Escala Y:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Escala el bloque en Y&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">Voltear bloque horizontal</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">Voltear bloque&lt;br&gt;verticalmente</translation>
    </message>
</context>
</TS>
